#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_identity_based_connection_pooling_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Enables identity-based-connection-pooling for the data source. When an application requests a database connection, WebLogic Server picks or creates a physical connection with requested DBMS identity based on a map of WebLogic user IDs and database IDs.  You must also specify the map of WebLogic Server user IDs to database user IDs (credential mapping). 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_identity_based_connection_pooling_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_identity_based_connection_pooling_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{datasource_name}/JDBCConnectionPoolParams/%{datasource_name}/IdentityBasedConnectionPoolingEnabled')
end
