#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_platform_mbean_server_used, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies whether WebLogic Server will use the platform MBean server for its Runtime MBean Server. Previously, WebLogic Server used the platform MBean server by default if it was enabled. This attribute provides a separation between enabling the platform MBean server and using it for WebLogic Server MBeans. The default value for this attribute is based on the <code>DomainVersion</code> attribute of the DomainMBean. If the domain version is prior to 10.3.3.0, then the default value of this attribute is <code>false</code> and the platform MBean server is not used. If the domain version is 10.3.3.0 or higher, then the default value of this attribute is <code>true</code> and the platform MBean server is used.  In this case, the server's Runtime MBean Server uses the <code>MBeanServer</code> returned by <code>java.lang.management.ManagementFactory.getPlatformMBeanServer()</code> method as its MBean Server. This makes it possible to access the WebLogic Server MBeans and the JVM platform MXBeans from a single MBean server. In addition, if you enable the Runtime MBean Server to be the Platform MBean Server, local processes in the JVM can directly access this MBean server through the <code>MBeanServer</code> interface that <code>java.lang.management.ManagementFactory.getPlatformMBeanServer()</code> returns. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_platform_mbean_server_used => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_platform_mbean_server_used']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JMX/%{domain_name}/PlatformMBeanServerUsed')
end
