#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_runtime_mbean_server_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies whether each server instance in the domain initializes its Runtime MBean Server, which provides access to a server's run-time MBeans and read-only configuration MBeans.  The Administration Console and the WebLogic Scripting Tool use this MBean server for some (but not all) of their read operations.  If <code>RuntimeMBeanServerEnabled</code> is <code>true</code>, each server starts its Runtime MBean Server during the server's startup cycle. If this attribute is <code>false</code>, no server instance in the domain will start its Runtime MBean Server. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_runtime_mbean_server_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_runtime_mbean_server_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JMX/%{domain_name}/RuntimeMBeanServerEnabled')
end
