#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:paging_io_buffer_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The I/O buffer size, in bytes, automatically rounded down to the nearest power of 2. <ul> <li>When a native <code>wlfileio</code> driver is available, the setting applies to off-heap (native) memory.</li> <li>When a native <code>wlfileio</code> driver is not available, the setting applies to JAVA heap memory.</li> <li>For the best runtime performance, Oracle recommends setting <code>PagingIOBufferSize</code> so that it is larger than the largest write (multiple concurrent store requests may be combined into a single write).</li> <li>See the JMS server runtime MBean attribute <code>PagingAllocatedIOBufferBytes</code> to find out the actual allocated off-heap (native) memory amount.</li> </ul> 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         paging_io_buffer_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:paging_io_buffer_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('PagingIoBufferSize')
end
