#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:target, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::ArrayProperty

  desc <<-EOD
    An array of target names.

    The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
    When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

        wls_coherence_cluster{ 'aCluster':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

    here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

        wls_cluster{ 'aCluster':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

  EOD

  maps_to('Targets/')

  on_apply do
    apply_paths_with_target(resource.target, resource.targettype)
  end

end


def target
  self[:target] ? self[:target].join(',') : ''
end

child_of(:wls_safagent) { autorequire_when('SAFAgent') }
child_of(:wls_server) { autorequire_when('Server') }
child_of(:wls_cluster) { autorequire_when('Cluster') }
child_of(:wls_jmsserver) { autorequire_when('JMSServer') }

def full_name(name)
  "#{domain}/#{name}"
end
