newproperty(:migration_restart_on_failure, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether or not a failed service will first be deactivated and reactivated in place, instead of being migrated.  The number of restart attempts is controlled by {@link #getNumberOfRestartAttempts}. Once these restart attempts are exhausted, the service will migrate. A restarting migratable target will deactivate all services on it in order, then reactivate them all. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         migration_restart_on_failure => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:migration_restart_on_failure']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('JTAMigratableTarget/%{server_name}/RestartOnFailure') {}
end
